# Mockingbird CocoaPods Example

A minimal example of [Mockingbird](https://github.com/birdrides/mockingbird) integrated into an Xcode project using CocoaPods.

Having issues setting up Mockingbird? Join the [Slack channel](https://slofile.com/slack/birdopensource) or [file an issue](https://github.com/birdrides/mockingbird/issues/new/choose).

## Tutorial

### 1. Add Dependency

Create the Podfile in the Xcode project root directory.

```console
$ cd iOSMockingbirdExample-CocoaPods
$ touch Podfile
```

Add Mockingbird as a dependency to the test target in the Podfile.

```ruby
target 'iOSMockingbirdExample-CocoaPodsTests' do
  use_frameworks!
  pod 'MockingbirdFramework', '~> 0.15'
end
```

### 2. Install Mockingbird

Initialize the pod and install the CLI.

```console
$ pod install
$ (cd Pods/MockingbirdFramework && make install-prebuilt)
```

### 3. Configure Test Target

Download the starter supporting source files into your project root.

```console
$ mockingbird download starter-pack
```

Then configure the test target.

```console
$ mockingbird install \
  --target iOSMockingbirdExample-CocoaPodsTests \
  --source iOSMockingbirdExample-CocoaPods
```

### 4. Run Tests

Open the Xcode workspace generated by CocoaPods.

```console
$ open iOSMockingbirdExample-CocoaPods.xcworkspace
```

Take a peek at the example test and sources and then run the tests (⌘+U).

- [`TreeTests.swift`](iOSMockingbirdExample-CocoaPodsTests/TreeTests.swift)
- [`Tree.swift`](iOSMockingbirdExample-CocoaPods/Tree.swift)
- [`Bird.swift`](iOSMockingbirdExample-CocoaPods/Bird.swift)

Bonus: 
- [`.mockingbird-ignore`](iOSMockingbirdExample-CocoaPods/.mockingbird-ignore)
- [`.gitignore`](.gitignore)
